@@ -1,7 +1,7 @@
 /*
  *  eCoach
  *
- *  Copyright (C) 2008  Jukka Alasalmi
+ *  Copyright (C) 2008  Jukka Alasalmi, Kai Skiftesvik
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -42,6 +42,8 @@
 #include "ec_error.h"
 #include "settings.h"
 #include "target_heart_rate.h"
+#include "calculate_bmi.h"
+#include "calculate_maxheartrate.h"
 #include "util.h"
 
 #include "debug.h"
@@ -330,18 +332,18 @@ static void interface_create_menu(AppData *app_data)
 
 	navigation_menu_item_new_for_path(
 			app_data->navigation_menu,
-			path_level_1,
+   			path_level_1,
 			_("BMI"),
-			NULL,
-			NULL,
-			NULL,
+			GFXDIR "menu_bmi_btn",
+			show_calculate_bmi,
+			app_data,
 			FALSE);
 
 	path_level_2 = navigation_menu_item_new_for_path(
 			app_data->navigation_menu,
 			path_level_1,
 			_("Maximum\nheart rate"),
-			NULL,
+			GFXDIR "menu_max_heart_btn",
 			NULL,
 			NULL,
 			TRUE);
@@ -350,9 +352,9 @@ static void interface_create_menu(AppData *app_data)
 			app_data->navigation_menu,
 			path_level_2,
 			_("Calculate"),
-			NULL,
-			NULL,
-			NULL,
+			GFXDIR "menu_calculate_btn",
+			show_calculate_maxheartrate,
+			app_data,
 			FALSE);
 
 	navigation_menu_item_new_for_path(
@@ -370,11 +372,11 @@ static void interface_create_menu(AppData *app_data)
 			app_data->navigation_menu,
 			path_level_1,
 			_("Target\nheart rate"),
-			NULL,
+			GFXDIR "menu_target_heart_btn",
 			target_heart_rate_dialog_show,
 			app_data,
 			FALSE);
-
+	/*
 	navigation_menu_item_new_for_path(
 			app_data->navigation_menu,
 			path_level_1,
@@ -383,7 +385,7 @@ static void interface_create_menu(AppData *app_data)
 			NULL,
 			NULL,
 			FALSE);
-
+	*/
 	gtk_tree_path_free(path_level_1);
 
 	path_level_1 = navigation_menu_item_new_for_path(
@@ -408,7 +410,7 @@ static void interface_create_menu(AppData *app_data)
 			app_data->navigation_menu,
 			path_level_1,
 			_("Heart rate\nmonitor"),
-			NULL,
+			GFXDIR "menu_hrm_btn",
 			hrm_settings_show,
 			app_data,
 			FALSE);
@@ -417,7 +419,7 @@ static void interface_create_menu(AppData *app_data)
 			app_data->navigation_menu,
 			path_level_1,
 			_("About"),
-			NULL,
+			GFXDIR "menu_about_btn",
 			interface_show_about_dialog,
 			app_data,
 			FALSE);
@@ -493,6 +495,8 @@ static void interface_minimize(GtkWidget *btn, gpointer user_data)
 static void interface_confirm_close(GtkWidget *btn, gpointer user_data)
 {
 	GtkWidget *dialog;
+	LocationGPSDControl *control;
+	
 	AppData *app_data = (AppData *)user_data;
 	gint result;
 
@@ -509,8 +513,12 @@ static void interface_confirm_close(GtkWidget *btn, gpointer user_data)
 
 	if(result == GTK_RESPONSE_OK)
 	{
+		
+		control = location_gpsd_control_get_default ();
+		location_gpsd_control_stop(control);
 		map_view_stop(app_data->map_view);
 		gtk_main_quit();
+		
 	}
 
 	DEBUG_END();
@@ -612,8 +620,9 @@ static void interface_show_about_dialog(
 	vbox = GTK_DIALOG(dialog)->vbox;
 
 	text_about = g_strdup_printf(_(
-				"eCoach version %s\n"
-				"Copyright (C) 2008 Jukka Alasalmi\n"),
+				"eCoach version %s Copyright (C) 2008 \n"
+				"Jukka Alasalmi Sampo Savola\n"
+				"Kai Skiftesvik Veli-Pekka Haajanen\n"),
 				PACKAGE_VERSION);
 	lbl_about = gtk_label_new(text_about);
 	g_free(text_about);
