@@ -4,7 +4,7 @@
  *  Copyright (C) 2008  Jukka Alasalmi
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
+ *  it under the terms of the GNU General Public License as published bylocation-distance-utils-fix
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
@@ -58,7 +58,7 @@
 
 #include "config.h"
 #include "debug.h"
-
+#include <gdk/gdkkeysyms.h>
 /*****************************************************************************
  * Definitions                                                               *
  *****************************************************************************/
@@ -71,7 +71,7 @@
 /*****************************************************************************
  * Private function prototypes                                               *
  *****************************************************************************/
-
+static void key_press_cb(GtkWidget * widget, GdkEventKey * event,MapView *self);
 static gboolean map_view_connect_beat_detector_idle(gpointer user_data);
 static gboolean map_view_load_map_idle(gpointer user_data);
 static void map_view_setup_progress_indicator(EcProgress *prg);
@@ -125,6 +125,7 @@ static void map_view_pause_activity(MapView *self);
 static void map_view_continue_activity(MapView *self);
 static void map_view_set_travelled_distance(MapView *self, gdouble distance);
 static void map_view_update_autocenter(MapView *self);
+static void map_view_units_clicked(GtkWidget *button, gpointer user_data);
 
 #if (MAP_VIEW_SIMULATE_GPS)
 static void map_view_simulate_gps(MapView *self);
@@ -173,6 +174,7 @@ MapView *map_view_new(
 
 	self->map_widget_state = MAP_VIEW_MAP_WIDGET_STATE_NOT_CONFIGURED;
 	self->has_gps_fix = FALSE;
+	self->metric = TRUE;
 
 	/* Main layout item		*/
 	self->main_widget = gtk_fixed_new();
@@ -408,7 +410,7 @@ MapView *map_view_new(
 	self->btn_start_pause = ec_button_new();
 	ec_button_set_bg_image(EC_BUTTON(self->btn_start_pause),
 			EC_BUTTON_STATE_RELEASED,
-			GFXDIR "ec_button_play.png");
+			GFXDIR "ec_button_rec.png");
 	ec_button_set_btn_down_offset(EC_BUTTON(self->btn_start_pause), 2);
 	ec_button_set_center_vertically(
 			EC_BUTTON(self->btn_start_pause),
@@ -471,6 +473,8 @@ MapView *map_view_new(
 			_("Speed"),
 			_("0.0 km/h"),
 			0, 1);
+	
+	
 
 	/* Average speed		*/
 	self->info_avg_speed = map_view_create_info_button(
@@ -501,7 +505,13 @@ MapView *map_view_new(
 	ec_button_set_icon_pixbuf(EC_BUTTON(self->info_heart_rate),
 			self->pxb_hrm_status[MAP_VIEW_HRM_STATUS_NOT_CONNECTED]
 			);
-
+	/* Distance unit */
+	
+	self->info_units = map_view_create_info_button(self,
+			 _("Units"), _("Metric"), 1, 2);
+	g_signal_connect(G_OBJECT(self->info_units), "clicked",
+			 G_CALLBACK(map_view_units_clicked), self);
+	
 	/* GPS device			*/
 #if (MAP_VIEW_SIMULATE_GPS)
 	self->show_map_widget_handler_id = 1;
@@ -591,12 +601,17 @@ void map_view_show(MapView *self)
 	}
 
 	/* Connect to GPS */
-	/** @todo: Request the status and act according to it */
+	/** @todo: Request the status and act according to it */	
 #if (MAP_VIEW_SIMULATE_GPS)
 	map_view_simulate_gps(self);
 #else
 	location_gpsd_control_start(self->gpsd_control);
 #endif
+	
+	g_signal_connect(G_OBJECT(self->parent_window), 
+			 "key_press_event", G_CALLBACK(key_press_cb), self);
+	
+	
 
 	DEBUG_END();
 }
@@ -617,15 +632,15 @@ void map_view_hide(MapView *self)
 					self);
 		}
 
-		location_gpsd_control_stop(self->gpsd_control);
+		
 
 		self->has_gps_fix = FALSE;
 		map_view_hide_map_widget(self);
 		track_helper_clear(self->track_helper, FALSE);
 		map_widget_clear_track(self->map_widget);
 		map_view_update_stats(self);
+		location_gpsd_control_stop(self->gpsd_control);
 	}
-
 	DEBUG_END();
 }
 
@@ -659,7 +674,7 @@ void map_view_stop(MapView *self)
 
 	ec_button_set_bg_image(EC_BUTTON(self->btn_start_pause),
 			EC_BUTTON_STATE_RELEASED,
-			GFXDIR "ec_button_play.png");
+			GFXDIR "ec_button_rec.png");
 
 	DEBUG_END();
 }
@@ -952,9 +967,10 @@ static void map_view_zoom_in(GtkWidget *widget, gpointer user_data)
 		DEBUG_END();
 		return;
 	}
+	hildon_banner_show_information(GTK_WIDGET(self->parent_window), NULL, "Zoom in");
 	zoom = zoom + 1;
 	map_widget_set_zoom(self->map_widget, zoom);
-
+	
 	DEBUG_END();
 }
 
@@ -973,8 +989,9 @@ static void map_view_zoom_out(GtkWidget *widget, gpointer user_data)
 		return;
 	}
 	zoom = zoom - 1;
+	hildon_banner_show_information(GTK_WIDGET(self->parent_window), NULL, "Zoom out");
 	map_widget_set_zoom(self->map_widget, zoom);
-
+	
 	DEBUG_END();
 }
 
@@ -1310,10 +1327,26 @@ static void map_view_btn_back_clicked(GtkWidget *button, gpointer user_data)
 	}
 
 	map_view_hide(self);
-
 	DEBUG_END();
 }
 
+
+static void map_view_units_clicked(GtkWidget *button, gpointer user_data)
+{
+	MapView *self = (MapView *)user_data;
+	if(self->metric)
+	{
+	ec_button_set_label_text(EC_BUTTON(self->info_units), _("English"));
+	self->metric = FALSE;
+	}
+	else
+	{
+	ec_button_set_label_text(EC_BUTTON(self->info_units), _("Metric"));
+	self->metric = TRUE;
+	}
+		
+}
+
 static void map_view_btn_start_pause_clicked(GtkWidget *button,
 		gpointer user_data)
 {
@@ -1404,10 +1437,12 @@ static void map_view_btn_autocenter_clicked(GtkWidget *button,
 		map_widget_set_auto_center(self->map_widget, FALSE);
 		ec_button_set_icon_pixbuf(EC_BUTTON(self->btn_autocenter),
 				self->pxb_autocenter_off);
+		hildon_banner_show_information(GTK_WIDGET(self->parent_window), NULL, "Map Centering off");
 	} else {
 		map_widget_set_auto_center(self->map_widget, TRUE);
 		ec_button_set_icon_pixbuf(EC_BUTTON(self->btn_autocenter),
 				self->pxb_autocenter_on);
+		hildon_banner_show_information(GTK_WIDGET(self->parent_window), NULL, "Map Centering on");
 	}
 
 	DEBUG_END();
@@ -1425,9 +1460,11 @@ static void map_view_update_autocenter(MapView *self)
 	{
 		ec_button_set_icon_pixbuf(EC_BUTTON(self->btn_autocenter),
 				self->pxb_autocenter_on);
+		
 	} else {
 		ec_button_set_icon_pixbuf(EC_BUTTON(self->btn_autocenter),
 				self->pxb_autocenter_off);
+		
 	}
 
 	DEBUG_END();
@@ -1515,7 +1552,7 @@ static void map_view_pause_activity(MapView *self)
 	self->activity_state = MAP_VIEW_ACTIVITY_STATE_PAUSED;
 	ec_button_set_bg_image(EC_BUTTON(self->btn_start_pause),
 			EC_BUTTON_STATE_RELEASED,
-			GFXDIR "ec_button_play.png");
+			GFXDIR "ec_button_rec.png");
 
 	DEBUG_END();
 }
@@ -1538,18 +1575,35 @@ static gboolean map_view_update_stats(gpointer user_data)
 	/* Travelled distance */
 	travelled_distance = track_helper_get_travelled_distance(
 			self->track_helper);
-
-	if(travelled_distance < 1000)
+	if(self->metric)
 	{
-		lbl_text = g_strdup_printf(_("%.0f m"), travelled_distance);
-	} else {
-		lbl_text = g_strdup_printf(_("%.1f km"),
-				travelled_distance / 1000.0);
+		if(travelled_distance < 1000)
+		{
+			lbl_text = g_strdup_printf(_("%.0f m"), travelled_distance);
+		} else {
+			lbl_text = g_strdup_printf(_("%.1f km"),
+					travelled_distance / 1000.0);
+		}
+
+		ec_button_set_label_text(EC_BUTTON(self->info_distance), lbl_text);
+		g_free(lbl_text);
 	}
+	else
+	{
+		
+		if(travelled_distance < 1609)
+		{
+			travelled_distance = travelled_distance * 3.28;
+			lbl_text = g_strdup_printf(_("%.0f ft"), travelled_distance);
+		} else {
+			travelled_distance = travelled_distance * 0.621;
+			lbl_text = g_strdup_printf(_("%.1f mi"),
+					travelled_distance / 1000.0);
+		}
 
-	ec_button_set_label_text(EC_BUTTON(self->info_distance), lbl_text);
-	g_free(lbl_text);
-
+		ec_button_set_label_text(EC_BUTTON(self->info_distance), lbl_text);
+		g_free(lbl_text);
+	}
 	/* Elapsed time */
 
 	/* Don't use the track_helper_get_elapsed_time(), because it
@@ -1571,26 +1625,65 @@ static gboolean map_view_update_stats(gpointer user_data)
 	avg_speed = track_helper_get_average_speed(self->track_helper);
 	if(avg_speed > 0.0)
 	{
+		if(self->metric)
+		{
 		lbl_text = g_strdup_printf(_("%.1f km/h"), avg_speed);
 		ec_button_set_label_text(EC_BUTTON(self->info_avg_speed),
 				lbl_text);
 		g_free(lbl_text);
+		}
+		else
+		{
+		avg_speed = avg_speed *	0.621;
+		lbl_text = g_strdup_printf(_("%.1f mph"), avg_speed);
+		ec_button_set_label_text(EC_BUTTON(self->info_avg_speed),
+					 lbl_text);
+		g_free(lbl_text);
+		}
 	} else {
+		if(self->metric)
+		{
 		ec_button_set_label_text(EC_BUTTON(self->info_avg_speed),
 				_("0 km/h"));
+		}
+		else
+		{
+		ec_button_set_label_text(EC_BUTTON(self->info_avg_speed),
+					_("0 mph"));		
+		}
 	}
 
 	/* Current speed */
+	
 	curr_speed = track_helper_get_current_speed(self->track_helper);
 	if(curr_speed > 0.0)
 	{
+		if(self->metric)
+		{
 		lbl_text = g_strdup_printf(_("%.1f km/h"), curr_speed);
 		ec_button_set_label_text(EC_BUTTON(self->info_speed),
 				lbl_text);
 		g_free(lbl_text);
+		}
+		else
+		{
+			curr_speed = curr_speed*0.621;
+			lbl_text = g_strdup_printf(_("%.1f mph"), curr_speed);
+			ec_button_set_label_text(EC_BUTTON(self->info_speed),
+					lbl_text);
+			g_free(lbl_text);
+		}
 	} else {
-		ec_button_set_label_text(EC_BUTTON(self->info_speed),
-				_("0 km/h"));
+		if(self->metric)
+		{
+			ec_button_set_label_text(EC_BUTTON(self->info_speed),
+						 _("0 km/h"));
+		}
+		else
+		{
+			ec_button_set_label_text(EC_BUTTON(self->info_speed),
+					_("0 mph"));
+		}
 	}
 
 	DEBUG_END();
@@ -1740,3 +1833,64 @@ static GdkPixbuf *map_view_load_image(const gchar *path)
 	gdk_pixbuf_ref(pxb);
 	return pxb;
 }
+static void key_press_cb(GtkWidget * widget, GdkEventKey * event, MapView *self){
+	
+	gboolean is_auto_center;
+	switch (event->keyval) {
+		
+		is_auto_center = map_widget_get_auto_center_status(self->map_widget);
+		g_return_if_fail(self != NULL);
+		DEBUG_BEGIN();
+		
+		case GDK_F6:
+			/*if(is_auto_center)
+			{
+				map_widget_set_auto_center(self->map_widget, FALSE);
+				//hildon_banner_show_information(GTK_WIDGET(self->parent_window), NULL, "Map Centering off");
+				map_view_update_autocenter(self);
+			
+			} else {
+				map_widget_set_auto_center(self->map_widget,
+						TRUE);
+				//hildon_banner_show_information(GTK_WIDGET(self->parent_window), NULL, "Map Centering on");
+				map_view_update_autocenter(self);
+			}
+			*/
+			map_view_btn_autocenter_clicked(NULL,self);
+			
+			
+		break;
+		case GDK_F7:
+			map_view_zoom_in(NULL,self);
+			
+		break;
+		
+		case GDK_F8:
+			map_view_zoom_out(NULL,self);
+	
+		break;
+		case GDK_Up:
+			
+			map_view_scroll_up(NULL,self);
+			break;
+		
+		case GDK_Down:
+			
+			map_view_scroll_down(NULL,self);
+			break;
+		case GDK_Left:
+			
+			map_view_scroll_left(NULL,self);
+			break;	
+		case GDK_Right:
+			
+			map_view_scroll_right(NULL,self);
+			break;
+		DEBUG_END();
+		
+
+		
+	}
+
+		
+		    }
